## About

ML.NET is a cross-platform open-source machine learning framework which makes machine learning accessible to .NET developers.

For more information, see the [ML.NET documentation](https://docs.microsoft.com/dotnet/machine-learning/).

This package adds the ability to use decision tree trainers and featurizers in ML.NET.

## Key Features

* Classification/Categorization - Automatically divide customer feedback into positive and negative categories
* Regression/Predict continuous values - Predict the price of houses based on size and location
* Recommendations - Suggest products that online shoppers may want to buy, based on their previous purchases

## How to Use

See [Machine Learning Samples](https://github.com/dotnet/machinelearning-samples) for an assortment of samples that show how to get started using ML.NET.

## Main Types

Some of the types provided by this library are:

* `Microsoft.ML.Trainers.FastForestBinaryTrainer`
* `Microsoft.ML.Trainers.FastForestRegressionTrainer`
* `Microsoft.ML.Trainers.FastTreeBinaryTrainer`
* `Microsoft.ML.Trainers.FastTreeRankingTrainer`
* `Microsoft.ML.Trainers.FastTreeRegressionTrainer`

## Additional Documentation

* [Conceptual documentation](https://learn.microsoft.com/en-us/dotnet/machine-learning/)
* [API documentation](https://learn.microsoft.com/en-us/dotnet/api/microsoft.ml.trainers.fastTree)

## Related Packages

* Main Package: [Microsoft.ML](https://www.nuget.org/packages/Microsoft.ML)
* Core data abstraction: [Microsoft.ML.DataView](https://www.nuget.org/packages/Microsoft.ML.DataView)
* LightGBM Model Support: [Microsoft.ML.LightGbm](https://www.nuget.org/packages/Microsoft.ML.LightGbm)
* Image analytics: [Microsoft.ML.ImageAnalytics](https://www.nuget.org/packages/Microsoft.ML.ImageAnalytics)
* Recommender: [Microsoft.ML.Recommender](https://www.nuget.org/packages/Microsoft.ML.Recommender)
* Time series: [Microsoft.ML.TimeSeries](https://www.nuget.org/packages/Microsoft.ML.TimeSeries)
* Automatic model selection / tuning:  [Microsoft.ML.AutoML](https://www.nuget.org/packages/Microsoft.ML.AutoML)
* Exporting Onnx Models: [Microsoft.ML.OnnxConverter](https://www.nuget.org/packages/Microsoft.ML.OnnxConverter)
* Loading Onnx models: [Microsoft.ML.OnnxTransformer](https://www.nuget.org/packages/Microsoft.ML.OnnxTransformer)
* Text tokenizers: [Microsoft.ML.Tokenizers](https://www.nuget.org/packages/Microsoft.ML.Tokenizers)

## Feedback & Contributing

Microsoft.ML is released as open source under the [MIT license](https://licenses.nuget.org/MIT). Bug reports and contributions are welcome at [the GitHub repository](https://github.com/dotnet/machinelearning).